# [Security](https://github.com/Pavel-Sushko/cve-tracker/security)

I take the security of my software products and services seriously, which includes all source code repositories managed through my [GitHub](https://github.com/Pavel-Sushko)

If you believe you have found a security vulnerability in any of my repositories that meets the [National Vulnerability Database's definition of a security vulnerability](https://nvd.nist.gov/vuln#:~:text=CVE%20defines%20a%20vulnerability%20as,confidentiality%2C%20integrity%2C%20or%20availability), please report it as described below.

## Reporting Security Issues

**Please do not report security vulnerabilities through public GitHub issues.**

Instead, please report them via GitHub's buil-in vulnerability [reporting](https://github.com/Pavel-Sushko/cve-tracker/security/advisories/new) feature. If you would rather submit the vulnerability via email, please do so at [vulnerabilities-github@sbsoftware.ca](mailto:vulnerabilities-github@sbsoftware.ca).

You should receive a response within 24 hours. If for some reason you do not, please follow up via email to ensure we received your original message.

Please include the requested information listed below (as much as you can provide) to help us better understand the nature and scope of the possible issue:

* Type of issue (e.g. buffer overflow, SQL injection, cross-site scripting, etc.)
* Full paths of source file(s) related to the manifestation of the issue
* The location of the affected source code (tag/branch/commit or direct URL)
* Any special configuration required to reproduce the issue
* Step-by-step instructions to reproduce the issue
* Proof-of-concept or exploit code (if possible)
* Impact of the issue, including how an attacker might exploit the issue

This information will help me triage your report more quickly.

## Preferred Languages

You can send your report in **English**, **Russian**, **French**, Spanish or Italian.

## Policy

I follow the principle of [Coordinated Vulnerability Disclosure](https://en.wikipedia.org/wiki/Coordinated_vulnerability_disclosure).

---
This document was adapted from Microsoft's [SECURITY.md](https://github.com/microsoft/.github/blob/main/SECURITY.md)
